*******
Authors
*******

Lead
====

- Steven Loria `@sloria <https://github.com/sloria>`_

Contributors (chronological)
============================

- Sebastian Vetter `@elbaschid <https://github.com/elbaschid>`_
- Eduard Carreras `@ecarreras <https://github.com/ecarreras>`_
- Joakim Ekberg `@kalasjocke <https://github.com/kalasjocke>`_
- Mark Grey `@DeaconDesperado <https://github.com/DeaconDesperado>`_
- Anders Steinlein `@asteinlein <https://github.com/asteinlein>`_
- Cyril Thomas `@Ketouem <https://github.com/Ketouem>`_
- Austin Macdonald `@asmacdo <https://github.com/asmacdo>`_
- Josh Carp `@jmcarp <https://github.com/jmcarp>`_
- `@amikholap <https://github.com/amikholap>`_
- Sven-Hendrik Haase `@svenstaro <https://github.com/svenstaro>`_
- Eric Wang `@ewang <https://github.com/ewang>`_
- `@philtay <https://github.com/philtay>`_
- `@malexer <https://github.com/malexer>`_
- Andriy Yurchuk `@Ch00k <https://github.com/Ch00k>`_
- Vesa Uimonen `@vesauimonen <https://github.com/vesauimonen>`_
- David Lord `@davidism <https://github.com/davidism>`_
- Daniel Castro `@0xDCA <https://github.com/0xDCA>`_
- Ben Jones `@RealSalmon <https://github.com/RealSalmon>`_
- Patrick Woods `@hakjoon <https://github.com/hakjoon>`_
- Lukas Heiniger `@3rdcycle <https://github.com/3rdcycle>`_
- Ryan Lowe `@ryanlowe0 <https://github.com/ryanlowe0>`_
- Jimmy Jia `@taion <https://github.com/taion>`_
- `@lustdante <https://github.com/lustdante>`_
- Sergey Aganezov, Jr. `@sergey-aganezov-jr <https://github.com/sergey-aganezov-jr>`_
